discord-continued
====================

**An API wrapper for Discord interactions.**

----

The current version is Stable however it's still very unrefined and requires a lot of work and documentation.

This Bot feaures chunks from old discord.py that I have repurposed for this library, as they work extremely well, however I don't intend on just taking over from what was left. A lot of the code is new and rewritten.

Installation
============

Use this line to install the library:

.. code-block:: bash

    pip install -U discord-continued
